{% extends 'base.html' %}

{% block title %}Data source{% endblock %}

{% block content %}
<p>name: {{ item.Name }}</p>
<p>method: {{ item.Method }}</p>
<p>url: {{ item.URL }}</p>
<a href="{% url 'datasource-remove' item.Name %}?TSURU_TOKEN={{ request.token }}">remove</a>
{% endblock %}
